==> entities_import-8.x-1.0.tar.gz: entities_import/src/DataStorage.php <==
<?php

namespace Drupal\entities_import;

use Drupal\node\Entity\Node;
use Drupal\entities_import\CommonUtilities;
use Drupal\entities_import\FileDetails;

/**
 * Defines class to data storage interface. 
 */
class DataStorage {

  /**
   * Defines method to save data. 
   */
  public static function save($item, &$context) {
    $flag = 0; 
    $txtstatus = '';
    if (count($item['unique_fields']) > 0) {
      if(!isset($item['node']['error'])) {
        if($item['entity_type'] === 'content_type') {
          $properties = CommonUtilities::generatePropertiesArray($item, 'type');
          $node = EntityDetails::checkNodeExistsByProperties($properties, 'node');       
          if(count($node) === 0) {
            $node = Node::create([
              'type' => $item['bundle'],            
            ]);
            
            foreach($item['node'] as $key => $value) {
              if(isset($item['node'][$key]['type']) && $item['node'][$key]['type'] === 'entity_reference_revisions') {
                $paragraph = self::getParagraphDetails($item['node'][$key]['value'], $item['node'][$key]['p_type']);
                $node->set($key, $paragraph);
              }
              else if(isset($value['type']) && in_array($value['type'], ['image', 'file'])) {
                if(!empty($value['value'])) {
                  if(is_array($value['value']) && count($value['value']) > 0) {
                    foreach($value['value'] as $file_key => $file_name) {
                      $fileID[] = FileDetails::create($file_name, $item['file_folder_path']);
                    }
                    $node->set($key, $fileID);
                  }
                  else {
                    $fileID = FileDetails::create($value['value'], $item['file_folder_path']);
                    $node->set($key, $fileID);
                  }
                }
              }
              else {
                $node->set($key, $value);
              }
            }
            if(!empty($item['title'])) {
              $node->set('title', $item['title']); 
            }            
            $node->set('uid', 1);     
            $txtstatus = t('Created Successfully');         
          }
          else {
            $node = reset($node);
            //$node = Node::load($nid);
            foreach($item['node'] as $key => $value) {          
              if(isset($item['node'][$key]['type']) && $item['node'][$key]['type'] === 'entity_reference_revisions') {
                $paragraph = self::getParagraphDetails($item['node'][$key]['value'], $item['node'][$key]['p_type']);
                $node->$key = $paragraph;
              }
              else if(isset($value['type']) && in_array($value['type'], ['image', 'file'])) {
                //\Drupal::logger('entities_import')->warning('<pre><code>' . print_r($node->get($key)->getValue(), TRUE) . '</code></pre>');
                if(!empty($node->get($key)->getValue())) {
                  FileDetails::delete($node->get($key)->getValue());
                }
                if(!empty($value['value'])) {
                  if(is_array($value['value']) && count($value['value']) > 0) {
                    foreach($value['value'] as $file_key => $file_name) {
                      $fileID[] = FileDetails::create($file_name, $item['file_folder_path']);
                    }
                    $node->$key = $fileID;
                  }
                  else {
                    $fileID = FileDetails::create($value['value'], $item['file_folder_path']);
                    $node->$key = $fileID;
                  }
                }
              }
              else {
                $node->$key = $value;
              }
            }  
            if(!empty($item['title'])) {
              $node->title = $item['title'];
            }
            $node->uid = 1;  
            $txtstatus = t('Updated Successfully');              
          }
          $node->save();
          $flag = 1; 
        }
        else if($item['entity_type'] === 'taxonomy') {
          $properties = CommonUtilities::generatePropertiesArray($item, 'vid');
          $term = EntityDetails::checkNodeExistsByProperties($properties, 'taxonomy_term');
          if(count($term) === 0) {
            $term = Term::create([
              'vid' => $item['bundle']
            ]);
            
            foreach($item['node'] as $key => $value) {
              if(isset($item['node'][$key]['type']) && $item['node'][$key]['type'] === 'entity_reference_revisions') {
                $paragraph = self::getParagraphDetails($item['node'][$key]['value'], $item['node'][$key]['p_type']);
                $term->set($key, $paragraph);
              }
              else if(isset($value['type']) && in_array($value['type'], ['image', 'file'])) {
                if(!empty($value['value'])) {
                  if(is_array($value['value']) && count($value['value']) > 0) {
                    foreach($value['value'] as $file_key => $file_name) {
                      $fileID[] = FileDetails::create($file_name, $item['file_folder_path']);
                    }
                    $term->set($key, $fileID);
                  }
                  else {
                    $fileID = FileDetails::create($value['value'], $item['file_folder_path']);
                    $term->set($key, $fileID);
                  }
                }
              }
              else {
                $term->set($key, $value);
              }
            }
            if(!empty($item['title'])) {
              $term->set('name', $item['title']);  
            }
            $txtstatus = t('Created Successfully');               
          }
          else {
            $term = reset($term);
            foreach($item['node'] as $key => $value) {
              if(isset($item['node'][$key]['type']) && $item['node'][$key]['type'] === 'entity_reference_revisions') {
                $paragraph = self::getParagraphDetails($item['node'][$key]['value'], $item['node'][$key]['p_type']);
                $term->$key = $paragraph;
              }
              else if(isset($value['type']) && in_array($value['type'], ['image', 'file'])) {
                if(!empty($value['value'])) {
                  if(is_array($value['value']) && count($value['value']) > 0) {
                    foreach($value['value'] as $file_key => $file_name) {
                      $fileID[] = FileDetails::create($file_name, $item['file_folder_path']);
                    }
                    $term->$key = $fileID;
                  }
                  else {
                    $fileID = FileDetails::create($value['value'], $item['file_folder_path']);
                    $term->$key = $fileID;
                  }
                }
              }
              else {
                $term->$key = $value;
              }
            } 
            if(!empty($item['title'])) {
              $term->name = $item['title'];
            }
            $txtstatus = t('Updated Successfully');               
          }
          $term->save();
          $flag = 1; 
        }
      }
      else {        
        foreach($item['node']['error'] as $key => $error) {
          $context['results']['error'][$item['row']][] = $error;
        }       
      }    
    } 
    if($flag == 1) {
      //$context['results'][] = $txtstatus . ' - ' . $item['title'];
      if(!isset($context['results']['count'])) {
        $context['results']['count'] = 0;
      }
      $context['results']['count'] = $context['results']['count'] + 1;
      $context['message'] = t('Created @title', array('@title' => $item['title']));      
    }
    else {
      //$context['results'][] = 'Failed to create - ' . $item['title'];      
    }
    
    
  }

  public static function getParagraphDetails($items, $p_type) {
    $paragraph = [];
    foreach($items as $key => $values) {
      $arr_paragraph = [];
      $arr_paragraph['type'] = $p_type;
      foreach($values as $field => $value) {
        $arr_paragraph[$field] = $value;
      }
      $paragraph[] = \Drupal\paragraphs\Entity\Paragraph::create($arr_paragraph);
    }
    return $paragraph;
  }
  public static function entities_import_batch_finished($success, $results, $operations) {   
    if ($success) {
      if(isset($results['count'])) {
        \Drupal::messenger()->addMessage(t('Total content created/updated') . ' : ' . $results['count'], 'status', TRUE);
      } 
      if(isset($results['error'])) {
        \Drupal::messenger()->addMessage(t('Content has not been created/updated for the below Row Number.'), 'warning', TRUE);
        foreach($results['error'] as $key => $result) {
          foreach($result as $value) {
            \Drupal::messenger()->addMessage(t('Row number') . ' : ' . $key .  ' - ' . $value, 'warning', TRUE);
          }        
        }
      }
    }
    else {      
      \Drupal::messenger()->addMessage(t('Finished with an error.'), 'error', TRUE); 
      foreach($results['error'] as $key => $result) {
        foreach($result as $value) {
          \Drupal::messenger()->addMessage(t('Row number') . ' : ' . $key .  ' - ' . $value, 'warning', TRUE);
        }        
      }
    }
    
  }
  
}

==> entities_import-8.x-1.1.tar.gz: entities_import/src/DataStorage.php <==
<?php

namespace Drupal\entities_import;

use Drupal\node\Entity\Node;
use Drupal\entities_import\CommonUtilities;
use Drupal\entities_import\FileDetails;
use Drupal\paragraphs\Entity\Paragraph;

/**
 * Defines class to data storage interface. 
 */
class DataStorage {

  /**
   * Defines method to save data. 
   */
  public static function save($item, &$context) {
    $flag = 0; 
    $txtstatus = '';
    if (count($item['unique_fields']) > 0) {
      if(!isset($item['node']['error'])) {
        if($item['entity_type'] === 'content_type') {
          $properties = CommonUtilities::generatePropertiesArray($item, 'type');
          $node = EntityDetails::checkNodeExistsByProperties($properties, 'node');       
          if(count($node) === 0) {
            $node = Node::create([
              'type' => $item['bundle'],            
            ]);
            
            foreach($item['node'] as $key => $value) {
              if(isset($item['node'][$key]['type']) && $item['node'][$key]['type'] === 'entity_reference_revisions') {
                $paragraph = self::getParagraphDetails($item['node'][$key]['value'], $item['node'][$key]['p_type']);
                $node->set($key, $paragraph);
              }
              else if(isset($value['type']) && in_array($value['type'], ['image', 'file'])) {
                if(!empty($value['value'])) {
                  if(is_array($value['value']) && count($value['value']) > 0) {
                    foreach($value['value'] as $file_key => $file_name) {
                      $fileID[] = FileDetails::create($file_name, $item['file_folder_path']);
                    }
                    $node->set($key, $fileID);
                  }
                  else {
                    $fileID = FileDetails::create($value['value'], $item['file_folder_path']);
                    $node->set($key, $fileID);
                  }
                }
              }
              else {
                $node->set($key, $value);
              }
            }
            if(!empty($item['title'])) {
              $node->set('title', $item['title']); 
            }            
            $node->set('uid', 1);     
            $txtstatus = t('Created Successfully');         
          }
          else {
            $node = reset($node);
            //$node = Node::load($nid);
            foreach($item['node'] as $key => $value) {          
              if(isset($item['node'][$key]['type']) && $item['node'][$key]['type'] === 'entity_reference_revisions') {
                $paragraph = $node->$key->getValue();
                self::deleteParagraphIfExists($paragraph);
                $paragraph = self::getParagraphDetails($item['node'][$key]['value'], $item['node'][$key]['p_type']);
                $node->$key = $paragraph;
              }
              else if(isset($value['type']) && in_array($value['type'], ['image', 'file'])) {
                //\Drupal::logger('entities_import')->warning('<pre><code>' . print_r($node->get($key)->getValue(), TRUE) . '</code></pre>');                
                if(!empty($node->get($key)->getValue()) && count($node->get($key)->getValue()) > 0) {
                  FileDetails::delete($node->get($key)->getValue());
                }
                if(!empty($value['value'])) {
                  if(is_array($value['value']) && count($value['value']) > 0) {
                    foreach($value['value'] as $file_key => $file_name) {
                      $fileID[] = FileDetails::create($file_name, $item['file_folder_path']);
                    }
                    $node->$key = $fileID;
                  }
                  else {
                    $fileID = FileDetails::create($value['value'], $item['file_folder_path']);
                    $node->$key = $fileID;
                  }
                }
                else {
                  $node->$key = [];
                }
              }
              else {
                $node->$key = $value;
              }
            }  
            if(!empty($item['title'])) {
              $node->title = $item['title'];
            }
            $node->uid = 1;  
            $txtstatus = t('Updated Successfully');              
          }
          $node->save();
          $flag = 1; 
        }
        else if($item['entity_type'] === 'taxonomy') {
          $properties = CommonUtilities::generatePropertiesArray($item, 'vid');
          $term = EntityDetails::checkNodeExistsByProperties($properties, 'taxonomy_term');
          if(count($term) === 0) {
            $term = Term::create([
              'vid' => $item['bundle']
            ]);
            
            foreach($item['node'] as $key => $value) {
              if(isset($item['node'][$key]['type']) && $item['node'][$key]['type'] === 'entity_reference_revisions') {
                $paragraph = self::getParagraphDetails($item['node'][$key]['value'], $item['node'][$key]['p_type']);
                $term->set($key, $paragraph);
              }
              else if(isset($value['type']) && in_array($value['type'], ['image', 'file'])) {
                if(!empty($value['value'])) {
                  if(is_array($value['value']) && count($value['value']) > 0) {
                    foreach($value['value'] as $file_key => $file_name) {
                      $fileID[] = FileDetails::create($file_name, $item['file_folder_path']);
                    }
                    $term->set($key, $fileID);
                  }
                  else {
                    $fileID = FileDetails::create($value['value'], $item['file_folder_path']);
                    $term->set($key, $fileID);
                  }
                }
              }
              else {
                $term->set($key, $value);
              }
            }
            if(!empty($item['title'])) {
              $term->set('name', $item['title']);  
            }
            $txtstatus = t('Created Successfully');               
          }
          else {
            $term = reset($term);
            foreach($item['node'] as $key => $value) {
              if(isset($item['node'][$key]['type']) && $item['node'][$key]['type'] === 'entity_reference_revisions') {
                $paragraph = $term->$key->getValue();
                self::deleteParagraphIfExists($paragraph);
                $paragraph = self::getParagraphDetails($item['node'][$key]['value'], $item['node'][$key]['p_type']);
                $term->$key = $paragraph;
              }
              else if(isset($value['type']) && in_array($value['type'], ['image', 'file'])) {
                if(!empty($value['value'])) {
                  if(is_array($value['value']) && count($value['value']) > 0) {
                    foreach($value['value'] as $file_key => $file_name) {
                      $fileID[] = FileDetails::create($file_name, $item['file_folder_path']);
                    }
                    $term->$key = $fileID;
                  }
                  else {
                    $fileID = FileDetails::create($value['value'], $item['file_folder_path']);
                    $term->$key = $fileID;
                  }
                }
                else {
                  $term->$key = [];
                }
              }
              else {
                $term->$key = $value;
              }
            } 
            if(!empty($item['title'])) {
              $term->name = $item['title'];
            }
            $txtstatus = t('Updated Successfully');               
          }
          $term->save();
          $flag = 1; 
        }
      }
      else {        
        foreach($item['node']['error'] as $key => $error) {
          $context['results']['error'][$item['row']][] = $error;
        }       
      }    
    } 
    if($flag == 1) {
      //$context['results'][] = $txtstatus . ' - ' . $item['title'];
      if(!isset($context['results']['count'])) {
        $context['results']['count'] = 0;
      }
      $context['results']['count'] = $context['results']['count'] + 1;
      $context['message'] = t('Created @title', array('@title' => $item['title']));      
    }
    else {
      //$context['results'][] = 'Failed to create - ' . $item['title'];      
    }
    
    
  }

  /**
   * Delete Paragraph if exists.
   */
  public static function deleteParagraphIfExists($paragraph) {  
    foreach ( $paragraph as $element ) {
      if(isset($element['target_id'])) {
        $paragraph_obj = Paragraph::load($element['target_id']);
        if(isset($paragraph_obj)) {
          $paragraph_obj->delete();
        } 
      }
    }
  }

  public static function getParagraphDetails($items, $p_type) {
    $paragraph = [];
    foreach($items as $key => $values) {
      $arr_paragraph = [];
      $arr_paragraph['type'] = $p_type;
      foreach($values as $field => $value) {
        $arr_paragraph[$field] = $value;
      }
      $paragraph[] = \Drupal\paragraphs\Entity\Paragraph::create($arr_paragraph);
    }
    return $paragraph;
  }
  public static function entities_import_batch_finished($success, $results, $operations) {   
    if ($success) {
      if(isset($results['count'])) {
        \Drupal::messenger()->addMessage(t('Total content created/updated') . ' : ' . $results['count'], 'status', TRUE);
      } 
      if(isset($results['error'])) {
        \Drupal::messenger()->addMessage(t('Content has not been created/updated for the below Row Number.'), 'warning', TRUE);
        foreach($results['error'] as $key => $result) {
          foreach($result as $value) {
            \Drupal::messenger()->addMessage(t('Row number') . ' : ' . $key .  ' - ' . $value, 'warning', TRUE);
          }        
        }
      }
    }
    else {      
      \Drupal::messenger()->addMessage(t('Finished with an error.'), 'error', TRUE); 
      foreach($results['error'] as $key => $result) {
        foreach($result as $value) {
          \Drupal::messenger()->addMessage(t('Row number') . ' : ' . $key .  ' - ' . $value, 'warning', TRUE);
        }        
      }
    }
    
  }
  
}
